@@ -2,11 +2,12 @@ use lib 't/lib';
 use strict;
 use warnings;
 
+use CGI::Snapp;
 use CGI::Snapp::Header;
 
 use Log::Handler;
 
-use Test::More tests => 16;
+use Test::More tests => 17;
 
 # ------------------------------------------------
 
@@ -81,3 +82,14 @@ ok($output =~ m|Content-Type: text/html|, "'Content-Type: text/html' present in
 ok($output =~ m|cooky_name=cooky_value;|, "'cooky_name=cooky_value;' present in default header");
 ok($output =~ m|domain=perl.org;|,        "'domain=perl.org;' present in default header");
 ok($output =~ m|path=/cooky_path;|,       "'path=/cooky_path;' present in default header");
+
+my($snapper)     = CGI::Snapp -> new;
+my(%old_headers) = $snapper -> header_props;
+my(%new_headers) = $snapper -> add_header(Status => 200, 'Content-Type' => 'text/html; charset=utf-8');
+
+is_deeply({'Content-Type' => 'text/html; charset=utf-8', Status => 200}, \%new_headers, 'add_header() works');
+
+#$logger -> log(debug => 'Old headers:');
+#$logger -> log(debug => "$_ => $old_headers{$_}") for sort keys %old_headers;
+#$logger -> log(debug => 'New headers:');
+#$logger -> log(debug => "$_ => $new_headers{$_}") for sort keys %new_headers;
